#[repr(u8)]pub enum CredentialType {
Programmingpin = 0,
Pin = 1,
Rfid = 2,
Fingerprint = 3,
Fingervein = 4,
Face = 5,
Alirocredentialissuerkey = 6,
Aliroevictableendpointkey = 7,
Alirononevictableendpointkey = 8,
}Variants
Programmingpin = 0
Programming PIN code credential type
Pin = 1
PIN code credential type
Rfid = 2
RFID identifier credential type
Fingerprint = 3
Fingerprint identifier credential type
Fingervein = 4
Finger vein identifier credential type
Face = 5
Face identifier credential type
Alirocredentialissuerkey = 6
A Credential Issuer public key as defined in Aliro
Aliroevictableendpointkey = 7
An Endpoint public key as defined in Aliro which can be evicted if space is needed for another endpoint key
Alirononevictableendpointkey = 8
An Endpoint public key as defined in Aliro which cannot be evicted if space is needed for another endpoint key
Implementations