#[repr(u8)]pub enum LockDataType {
Show 14 variants
Unspecified = 0,
Programmingcode = 1,
Userindex = 2,
Weekdayschedule = 3,
Yeardayschedule = 4,
Holidayschedule = 5,
Pin = 6,
Rfid = 7,
Fingerprint = 8,
Fingervein = 9,
Face = 10,
Alirocredentialissuerkey = 11,
Aliroevictableendpointkey = 12,
Alirononevictableendpointkey = 13,
}Variants
Unspecified = 0
Unspecified or manufacturer specific lock user data added, cleared, or modified.
Programmingcode = 1
Lock programming PIN code was added, cleared, or modified.
Userindex = 2
Lock user index was added, cleared, or modified.
Weekdayschedule = 3
Lock user week day schedule was added, cleared, or modified.
Yeardayschedule = 4
Lock user year day schedule was added, cleared, or modified.
Holidayschedule = 5
Lock holiday schedule was added, cleared, or modified.
Pin = 6
Lock user PIN code was added, cleared, or modified.
Rfid = 7
Lock user RFID code was added, cleared, or modified.
Fingerprint = 8
Lock user fingerprint was added, cleared, or modified.
Fingervein = 9
Lock user finger-vein information was added, cleared, or modified.
Face = 10
Lock user face information was added, cleared, or modified.
Alirocredentialissuerkey = 11
An Aliro credential issuer key credential was added, cleared, or modified.
Aliroevictableendpointkey = 12
An Aliro endpoint key credential which can be evicted credential was added, cleared, or modified.
Alirononevictableendpointkey = 13
An Aliro endpoint key credential which cannot be evicted was added, cleared, or modified.
Implementations