#[repr(u8)]pub enum OperationSource {
Unspecified = 0,
Manual = 1,
Proprietaryremote = 2,
Keypad = 3,
Auto = 4,
Button = 5,
Schedule = 6,
Remote = 7,
Rfid = 8,
Biometric = 9,
Aliro = 10,
}Variants
Unspecified = 0
Lock/unlock operation came from unspecified source
Manual = 1
Lock/unlock operation came from manual operation (key, thumbturn, handle, etc).
Proprietaryremote = 2
Lock/unlock operation came from proprietary remote source (e.g. vendor app/cloud)
Keypad = 3
Lock/unlock operation came from keypad
Auto = 4
Lock/unlock operation came from lock automatically (e.g. relock timer)
Button = 5
Lock/unlock operation came from lock button (e.g. one touch or button)
Schedule = 6
Lock/unlock operation came from lock due to a schedule
Remote = 7
Lock/unlock operation came from remote node
Rfid = 8
Lock/unlock operation came from RFID card
Biometric = 9
Lock/unlock operation came from biometric source (e.g. face, fingerprint/fingervein)
Aliro = 10
Lock/unlock operation came from an interaction defined in Aliro, or user change operation was a step-up credential provisioning as defined in Aliro
Implementations